@@ -36,7 +36,7 @@ cols=c(colSpeed,colForce,colPower); lty=rep(1,3)
 #way A. passing options to a file
 getOptionsFromFile <- function(optionsFile) {
 	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=18)
+	options=readLines(optionsCon,n=19)
 	close(optionsCon)
 	return (options)
 }
@@ -55,8 +55,10 @@ options=getOptionsFromFile(optionsFile);
 
 print(options)
 
-OutputData2=options[4] #currently used to display processing feedback
-OperatingSystem=options[18]
+OutputData2 = options[4] #currently used to display processing feedback
+SpecialData = options[5]
+OperatingSystem=options[19]
+
 
 write("(1/5) Starting R", OutputData2)
 
@@ -78,8 +80,22 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 		if(b$maxindex[1] < b$minindex[1]) { b$minindex = rbind(c(1,1),b$minindex) } 
 		row=1; i=1; j=1
 		while(max(c(i,j)) <= min(c(length(b$minindex[,1]),length(b$maxindex[,1])))) {
+
+			#tempStart at the end of minindexs
+			#tempStart = b$minindex[i,2]
+			
+			#tempStart at the mean of minindexs
+			#this is better because has more data in order to reduceCurveBySpeed
+			#then we get similar results than pyserial_pyper.py
 			tempStart = mean(c(b$minindex[i,1],b$minindex[i,2]))
-			tempEnd = mean(c(b$maxindex[j,1],b$maxindex[j,2]))
+			
+			
+			#end at the mean of maximum values
+			#tempEnd = mean(c(b$maxindex[j,1],b$maxindex[j,2]))
+
+			#end at the first maximum value
+			tempEnd = b$maxindex[j,1]
+			
 			height=a[tempEnd]-a[tempStart]
 #			print(paste(height,i,j))
 			if(height >= min_height) { 
@@ -146,10 +162,19 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 		     type="l",
 		     xlim=c(1,length(a))/1000,		#ms -> s
 		     xlab="",ylab="",axes=T) 
+		
 		title(title, cex.main=1, font.main=1)
 		mtext("time (s) ",side=1,adj=1,line=-1)
 		mtext("height (cm) ",side=2,adj=1,line=-1)
 		abline(v=b$maxindex/1000,lty=3); abline(v=b$minindex/1000,lty=3)	#ms -> s
+	
+		#plot speed (currently disabled)	
+		#speed <- smooth.spline( 1:length(rawdata), rawdata, spar=smoothingAll)
+		#abline(h=0,lty=2,col="yellow")
+	        #lines((1:length(rawdata))/1000, speed$y*10, col="green")
+		#print("SPEEEDYYYY")
+		#print(max(speed$y))	
+		#print(min(speed$y))	
 	}
 	return(as.data.frame(cbind(start,end,startH)))
 }
@@ -160,6 +185,11 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 #if this changes, change also in python capture file
 reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothingOneEC, smoothingOneC) {
 	a=rawdata
+	
+	#debug
+	#print("startT and aaaaaaaaaaaaaaaaaaaaaaa")
+	#print(startT)
+	#print(a)
 
 	smoothing = 0
 	if(eccon == "c")
@@ -168,9 +198,6 @@ reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothingOneEC, smoo
 	speed <- smooth.spline( 1:length(a), a, spar=smoothing) 
 	b=extrema(speed$y)
 
-	#find the b$cross at left of max speed
-	x.ini=1
-	
 	#from searchValue, go to the left, searchValue is at max speed on going up
 	#but is min speed on going down (this happens when not "concentric" and when phase is odd (impar)
 	searchValue = max(speed$y)
@@ -181,9 +208,28 @@ reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothingOneEC, smoo
 
 	maxSpeedT <- min(which(speed$y == searchValue))
 	
-	for(i in b$cross[,2]) 		{ if(i < maxSpeedT) { x.ini = i } } #left adjust
+	#left adjust
+	#find the b$cross at left of max speed
+		
+	x.ini = 0 #good to declare here
+	bcrossLen = length(b$cross[,2])
+	if(bcrossLen == 0)
+		x.ini = 0
+	else if(bcrossLen == 1)
+		x.ini = b$cross[,2]
+	else 
+		for(i in b$cross[,2]) 
+			if(i < maxSpeedT) 
+				x.ini = i
 
-	return(startT+x.ini)
+	#debug
+	#print(b)
+	print(b$cross[,2])
+	#print(bcrossLen)
+	#print(maxSpeedT)
+	print(x.ini)
+
+	return(startT + x.ini)
 }
 
 findECPhases <- function(a,speed) {
@@ -247,8 +293,6 @@ return (propulsiveEnd)
 #eccon="ec" one time each curve
 #eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
 kinematicsF <- function(a, mass, smoothingOneEC, smoothingOneC, g, eccon, analysisOptions) {
-	print("length unique x in spline")
-	print(length(unique(1:length(a))))
 
 	smoothing = 0
 	if(eccon == "c")
@@ -265,8 +309,8 @@ kinematicsF <- function(a, mass, smoothingOneEC, smoothingOneC, g, eccon, analys
 	concentric = 0
 	propulsiveEnd = 0
 
-print("at kinematicsF eccon==")
-print(eccon)
+#print("at kinematicsF eccon==")
+#print(eccon)
 
 	#search propulsiveEnd
 	if(analysisOptions == "p") {
@@ -292,6 +336,9 @@ print("WARNING ECS\n\n\n\n\n")
 
 	power <- force*speed$y
 
+	#print("propulsiveEnd")
+	#print(propulsiveEnd)
+
 	if( analysisOptions == "p" && ( eccon== "c" || eccon == "ec" ) )
 		return(list(speedy=speed$y[1:propulsiveEnd], accely=accel$y[1:propulsiveEnd], 
 			    force=force[1:propulsiveEnd], power=power[1:propulsiveEnd], mass=mass))
@@ -300,6 +347,9 @@ print("WARNING ECS\n\n\n\n\n")
 }
 
 powerBars <- function(eccon, kinematics) {
+	#print("speed$y")
+	#print(kinematics$speedy)
+
 	meanSpeed <- mean(kinematics$speedy)
 	#max speed and max speed time can be at eccentric or concentric
 	maxSpeed <- max(abs(kinematics$speedy))
@@ -316,6 +366,7 @@ powerBars <- function(eccon, kinematics) {
 	meanForce <- mean(kinematics$force)
 	maxForce <- max(abs(kinematics$force))
 
+
 	#here paf is generated
 	#mass is not used by powerBars, but used by Kg/W (loadVSPower)
 	#meanForce and maxForce are not used by powerBars, but used by F/S (forceVSSpeed)
@@ -351,7 +402,7 @@ kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOneEC,smooth
 
 paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highlight,
 	startX, startH, smoothingOneEC, smoothingOneC, mass, title, subtitle, draw, showLabels, marShrink, showAxes, legend,
-	Analysis, AnalysisOptions, ExercisePercentBodyWeight 
+	Analysis, AnalysisOptions, exercisePercentBodyWeight 
 	) {
 
 	meanSpeedE = 0
@@ -395,7 +446,8 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 
 		title(main=title,line=-2,outer=T)
 		mtext(subtitle,side=1,adj=0,cex=.8)
-		
+	
+
 		if(showAxes) {
 			axis(1) 	#can be added xmin
 			axis(2)
@@ -418,6 +470,15 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		abline(h=0,lty=3,col="black")
 
 		#abline(v=seq(from=0,to=length(a),by=500),lty=3,col="gray")
+
+
+#print("ROTARY")		
+#print(max(yValues))
+#print(max(yValues)/2)
+#print(mean(which(yValues == max(yValues)/2)))
+#abline(h=round(mean(which(yValues == max(yValues)/2)),0))
+#abline(v=round(mean(which(yValues == max(yValues)/2)),0))
+
 	}
 
 	#speed
@@ -616,7 +677,7 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	#if it was a eccon concentric-eccentric, will be useful to calculate flight time
 	#but this eccon will be not done
 	#if(draw & (!superpose || (superpose & highlight)) & isJump) {
-	if(draw & (!superpose || (superpose & highlight)) & ExercisePercentBodyWeight == 100) {
+	if(draw & (!superpose || (superpose & highlight)) & exercisePercentBodyWeight == 100) {
 		weight=mass*9.81
 		abline(h=weight,lty=1,col=cols[2]) #body force, lower than this, person in the air (in a jump)
 		takeoff = max(which(force>=weight))
@@ -863,7 +924,7 @@ addUnits <- function (var) {
 }
 
 #option: mean or max
-paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, seriesName) {
+paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, seriesName, do1RM, do1RMMethod, outputData1) {
 	x = (paf[,findPosInPaf(varX, option)])
 	y = (paf[,findPosInPaf(varY, option)])
 
@@ -908,14 +969,78 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 			colBalls="red"
 			bgBalls="pink"
 		}
+		
 		plot(x,y, xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
 	
-		#x vector should contain at least 4 different values
-		if(length(unique(x)) >= 4)
-			lines(smooth.spline(x,y,df=4),col=colBalls,lwd=2)
+		if(do1RM != FALSE & do1RM != "0") {	
+			speed1RM = as.numeric(do1RM)
+
+			print("speed1RM")
+			print(speed1RM)
+			
+			#lineal stuff
+			fit = lm(y ~ x) #declare
+			if(do1RMMethod == "NONWEIGHTED")  {
+				#without weights
+				fit = lm(y ~ x)
+			} else if(do1RMMethod == "WEIGHTED")  {
+				#weights x
+				fit = lm(y ~ x, weights=x/max(x)) 
+				print(x/max(x))
+			} else if(do1RMMethod == "WEIGHTED2")  {
+				#weights x^2
+				fit = lm(y ~ x, weights=x^2/max(x^2)) 
+				print(x^2/max(x^2))
+			} else if(do1RMMethod == "WEIGHTED3")  {
+				#weights x^3 (as higher then more important are the right values) 
+				fit = lm(y ~ x, weights=x^3/max(x^3)) 
+				print(x^3/max(x^3))
+			}
+
+			c.intercept = coef(fit)[[1]]
+			c.x = coef(fit)[[2]]
+
+			if(is.na(c.x)) {
+				plot(0,0,type="n",axes=F,xlab="",ylab="")
+				text(x=0,y=0,"Not enough data.",cex=1.5)
+				dev.off()
+				write("1RM;-1", SpecialData)
+				write("", outputData1)
+				quit()
+			}
+
+			load1RM = ( speed1RM - c.intercept ) / c.x
+
+			#plot(x,y, xlim=c(min(x),load1RM), ylim=c(speed1RM, max(y)), xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
+			maxX=max(x)
+			if(load1RM > maxX)
+				maxX=load1RM
+			plot(x,y, xlim=c(min(x),maxX), ylim=c(0, max(y)), xlab=varX, ylab="", pch=21,col=colBalls,bg=bgBalls,cex=cexBalls,axes=F)
+			abline(fit,col="red")
+			abline(h=speed1RM,col="gray",lty=2)
+			abline(v=load1RM,col="gray",lty=2)
+			mtext("1RM", at=load1RM, side=1, line=2,col="red")
+			mtext(round(load1RM,2), at=load1RM, side=1, line=3,col="red")
+			mtext("1RM", at=speed1RM, side=2, line=2,col="red")
+			mtext(speed1RM, at=speed1RM, side=2, line=3,col="red")
+			points(load1RM,speed1RM,cex=2,col="red")
+
+			write(paste("1RM;",round(load1RM,2),sep=""), SpecialData)
+
+			#quadratic stuff
+			#fit2 = lm(y ~ I(x^2) + x)
+			#fit2line = predict(fit2, data.frame(x = 10:100))
+			#lines(10:100 ,fit2line, col="red") #puts line on plot
+		}
+		else {
+			#x vector should contain at least 4 different values
+			if(length(unique(x)) >= 4)
+				lines(smooth.spline(x,y,df=4),col=colBalls,lwd=2)
+		}
 		
 		title(title, cex.main=1, font.main=2)
 		text(x,y,nums,adj=c(adjHor,.5),cex=cexNums)
+		
 
 	} else { #more than one series
 		#colBalls = "black"
@@ -974,7 +1099,7 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 }
 
 #propulsive!!!!
-paint1RMBadillo2010 <- function (paf, title) {
+paint1RMBadillo2010 <- function (paf, title, outputData1) {
 	curvesLoad = (paf[,findPosInPaf("Load","")]) 		#mass: X
 	curvesSpeed = (paf[,findPosInPaf("Speed", "mean")])	#mean speed Y
 
@@ -997,8 +1122,12 @@ paint1RMBadillo2010 <- function (paf, title) {
 	curvesSpeedInIntervalPos = which(curvesSpeed <= max(msp))
 
 	if(length(curvesSpeedInIntervalPos) == 0) {
-		plot(x=0,xlab="",ylab="",axes=F,type="n")
-		return()
+		plot(0,0,type="n",axes=F,xlab="",ylab="")
+		text(x=0,y=0,"Not enough data.",cex=1.5)
+		dev.off()
+		write("1RM;-1", SpecialData)
+		write("", outputData1)
+		quit()
 	}
 
 	par(mar=c(6,5,3,4))
@@ -1026,6 +1155,8 @@ paint1RMBadillo2010 <- function (paf, title) {
 
 	segments(predicted1RM,0.185,predicted1RM,0,lty=1)
 	mtext(side=1, at=predicted1RM, round(predicted1RM,2), cex=.8)
+			
+	write(paste("1RM;",round(predicted1RM,2),sep=""), SpecialData)
 }
 
 			
@@ -1077,26 +1208,28 @@ doProcess <- function(options) {
 	OutputGraph=options[2]
 	OutputData1=options[3]
 	OutputData2=options[4] #currently used to display processing feedback
-	MinHeight=as.numeric(options[5])*10 #from cm to mm
-	ExercisePercentBodyWeight=as.numeric(options[6])	#was isJump=as.logical(options[6])
-	Mass=as.numeric(options[7])
-	Eccon=options[8]
-	Analysis=options[9]	#in cross comes as "cross.Force.Speed.mean"
-	AnalysisOptions=options[10]	#p: propulsive
-	SmoothingOneEC=options[11]
-	SmoothingOneC=options[12]
-	Jump=options[13]
-	Width=as.numeric(options[14])
-	Height=as.numeric(options[15])
-	DecimalSeparator=options[16]
-	Title=options[17]
-	OperatingSystem=options[18]	#if this changes, change it also at start of this R file
+	SpecialData=options[5] #currently used to write 1RM. variable;result (eg. "1RM;82.78")
+	MinHeight=as.numeric(options[6])*10 #from cm to mm
+	ExercisePercentBodyWeight=as.numeric(options[7])	#was isJump=as.logical(options[6])
+	Mass=as.numeric(options[8])
+	Eccon=options[9]
+	Analysis=options[10]	#in cross comes as "cross;Force;Speed;mean"
+	AnalysisOptions=options[11]	#p: propulsive
+	SmoothingOneEC=options[12]
+	SmoothingOneC=options[13]
+	Jump=options[14]
+	Width=as.numeric(options[15])
+	Height=as.numeric(options[16])
+	DecimalSeparator=options[17]
+	Title=options[18]
+	OperatingSystem=options[19]	#if this changes, change it also at start of this R file
 	#important, if this grows, change the readLines value on getOptionsFromFile
 
 	print(File)
 	print(OutputGraph)
 	print(OutputData1)
 	print(OutputData2)
+	print(SpecialData)
 	
 	if(Analysis != "exportCSV") {
 		if(OperatingSystem=="Windows")
@@ -1144,7 +1277,7 @@ doProcess <- function(options) {
 		start = NULL; end = NULL; startH = NULL
 		status = NULL; id = NULL; exerciseName = NULL; mass = NULL; smooth = NULL
 		dateTime = NULL; myEccon = NULL; curvesHeight = NULL
-		seriesName = NULL
+		seriesName = NULL; percentBodyWeight = NULL;
 
 		newLines=0;
 		countLines=1; #useful to know the correct ids of active curves
@@ -1193,6 +1326,7 @@ doProcess <- function(options) {
 				mass[(i+newLines)] = inputMultiData$mass[i]
 				#smooth[(i+newLines)] = inputMultiData$smoothingOne[i] #unused since 1.3.7
 				dateTime[(i+newLines)] = as.vector(inputMultiData$dateTime[i])
+				percentBodyWeight[(i+newLines)] = as.vector(inputMultiData$percentBodyWeight[i])
 
 				curvesHeight[(i+newLines)] = sum(dataTempPhase)
 
@@ -1230,10 +1364,12 @@ doProcess <- function(options) {
 		#solution:
 		if(length(id)==1) {
 			curves = data.frame(start,end,startH,exerciseName,mass,
-					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=id)
+					    dateTime,myEccon,seriesName,percentBodyWeight,
+					    stringsAsFactors=F,row.names=id)
 		} else {
 			curves = data.frame(id,start,end,startH,exerciseName,mass,
-					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=1)
+					    dateTime,myEccon,seriesName,percentBodyWeight,
+					    stringsAsFactors=F,row.names=1)
 		}
 
 		n=length(curves[,1])
@@ -1295,11 +1431,14 @@ doProcess <- function(options) {
 			myEccon = Eccon
 			myStart = curves[Jump,1]
 			myEnd = curves[Jump,2]
+			myExPercentBodyWeight = ExercisePercentBodyWeight
 			if(! singleFile) {
 				myMass = curves[Jump,5]
 				#mySmoothingOne = curves[Jump,6]
 				myEccon = curves[Jump,7]
+				myExPercentBodyWeight = curves[Jump,9]
 			}
+			
 			myCurveStr = paste("curve=", Jump, ", ", myMass, "Kg", sep="")
 			paint(rawdata, myEccon, myStart, myEnd,"undefined","undefined",FALSE,FALSE,
 			      1,curves[Jump,3],SmoothingOneEC,SmoothingOneC,myMass,
@@ -1310,7 +1449,7 @@ doProcess <- function(options) {
 			      FALSE,	#marShrink
 			      TRUE,	#showAxes
 			      TRUE,	#legend
-			      Analysis, AnalysisOptions, ExercisePercentBodyWeight 
+			      Analysis, AnalysisOptions, myExPercentBodyWeight 
 			      )	
 		}
 	}
@@ -1330,10 +1469,12 @@ doProcess <- function(options) {
 			myMass = Mass
 			#mySmoothingOne = SmoothingOne
 			myEccon = Eccon
+			myExPercentBodyWeight = ExercisePercentBodyWeight
 			if(! singleFile) {
 				myMass = curves[i,5]
 				#mySmoothingOne = curves[i,6]
 				myEccon = curves[i,7]
+				myExPercentBodyWeight = curves[i,9]
 			}
 
 			myTitle = ""
@@ -1349,63 +1490,64 @@ doProcess <- function(options) {
 			      TRUE,	#marShrink
 			      FALSE,	#showAxes
 			      FALSE,	#legend
-			      Analysis, AnalysisOptions, ExercisePercentBodyWeight 
+			      Analysis, AnalysisOptions, myExPercentBodyWeight 
 			      )
 		}
 		par(mfrow=c(1,1))
 	}
-	if(Analysis=="superpose") {	#TODO: fix on ec startH
-		#falta fer un graf amb les 6 curves sobreposades i les curves de potencia (per exemple) sobrepossades
-		#fer que acabin al mateix punt encara que no iniciin en el mateix
-		#arreglar que els eixos de l'esq han de seguir un ylim,
-		#pero els de la dreta un altre, basat en el que es vol observar
-		#fer que es pugui enviar colors que es vol per cada curva, o linetypes
-		wide=max(curves$end-curves$start)
-
-		#a=cumsum(rawdata)
-		#yrange=c(min(a),max(a))
-		yrange=find.yrange(singleFile, rawdata,curves)
-
-		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOneEC,SmoothingOneC,g,Eccon,AnalysisOptions)
-		for(i in 1:n) {
-			#in superpose all jumps end at max height
-			#start can change, some are longer than other
-			#xmin and xmax should be the same for all in terms of X concordance
-			#but line maybe don't start on the absolute left
-			#this is controled by startX
-			startX = curves[i,1]-(curves[i,2]-wide)+1;
-			myTitle = "";
-			if(i==1)
-				myTitle = paste(titleType,Jump);
-
-			paint(rawdata, Eccon, curves[i,2]-wide,curves[i,2],yrange,knRanges,TRUE,(i==Jump),
-			      startX,curves[i,3],SmoothingOneEC,SmoothingOneC,Mass,myTitle,"",
-			      TRUE,	#draw
-			      TRUE,	#showLabels
-			      FALSE,	#marShrink
-			      (i==1),	#showAxes
-			      TRUE,	#legend
-			      Analysis, AnalysisOptions, ExercisePercentBodyWeight 
-			      )
-			par(new=T)
-		}
-		par(new=F)
-		#print(knRanges)
-	}
+#	if(Analysis=="superpose") {	#TODO: fix on ec startH
+#		#falta fer un graf amb les 6 curves sobreposades i les curves de potencia (per exemple) sobrepossades
+#		#fer que acabin al mateix punt encara que no iniciin en el mateix
+#		#arreglar que els eixos de l'esq han de seguir un ylim,
+#		#pero els de la dreta un altre, basat en el que es vol observar
+#		#fer que es pugui enviar colors que es vol per cada curva, o linetypes
+#		wide=max(curves$end-curves$start)
+#
+#		#a=cumsum(rawdata)
+#		#yrange=c(min(a),max(a))
+#		yrange=find.yrange(singleFile, rawdata,curves)
+#
+#		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOneEC,SmoothingOneC,g,Eccon,AnalysisOptions)
+#		for(i in 1:n) {
+#			#in superpose all jumps end at max height
+#			#start can change, some are longer than other
+#			#xmin and xmax should be the same for all in terms of X concordance
+#			#but line maybe don't start on the absolute left
+#			#this is controled by startX
+#			startX = curves[i,1]-(curves[i,2]-wide)+1;
+#			myTitle = "";
+#			if(i==1)
+#				myTitle = paste(titleType,Jump);
+#
+#			paint(rawdata, Eccon, curves[i,2]-wide,curves[i,2],yrange,knRanges,TRUE,(i==Jump),
+#			      startX,curves[i,3],SmoothingOneEC,SmoothingOneC,Mass,myTitle,"",
+#			      TRUE,	#draw
+#			      TRUE,	#showLabels
+#			      FALSE,	#marShrink
+#			      (i==1),	#showAxes
+#			      TRUE,	#legend
+#			      Analysis, AnalysisOptions, ExercisePercentBodyWeight 
+#			      )
+#			par(new=T)
+#		}
+#		par(new=F)
+#		#print(knRanges)
+#	}
 
 	#since Chronojump 1.3.6, encoder analyze has a treeview that can show the curves
 	#when an analysis is done, curves file has to be written
 	writeCurves = TRUE
 
 	#Analysis in cross variables comes as:
-	#"cross.Speed.Force.mean" 	#2nd is Y, 3d is X. "mean" can also be "max"
+	#"cross;Speed;Force;mean" 	#2nd is Y, 3d is X. "mean" can also be "max"
 	#there's a double XY plot:
-	#"cross.Speed,Power.Load.mean" 	#Speed,power are Y (left and right), 3d: Load is X.
-	analysisCross = unlist(strsplit(Analysis, "\\."))
+	#"cross;Speed,Power;Load;mean" 	#Speed,power are Y (left and right), 3d: Load is X.
+	#in 1RMAnyExercise: "1RMAnyExercise;0.185;method" speed1RM = 0.185m/s
+	analysisCross = unlist(strsplit(Analysis, "\\;"))
 	if(
 	   Analysis == "powerBars" || analysisCross[1] == "cross" || 
-	   Analysis == "1RMBadillo2010" || Analysis == "curves" ||
-	   writeCurves) 
+	   Analysis == "1RMBadillo2010" || analysisCross[1] == "1RMAnyExercise" || 
+	   Analysis == "curves" || writeCurves) 
 	{
 		paf = data.frame()
 		discardedCurves = NULL
@@ -1420,13 +1562,13 @@ doProcess <- function(options) {
 				myEccon = curves[i,7]
 
 				#only use concentric data	
-				if(Analysis == "1RMBadillo2010" & myEccon == "e") {
+				if( (Analysis == "1RMBadillo2010" || analysisCross[1] == "1RMAnyExercise") & myEccon == "e") {
 					discardedCurves = c(i,discardedCurves)
 					discardingCurves = TRUE
 					next;
 				}
 			} else {
-				if(Analysis == "1RMBadillo2010" & Eccon == "ecS" & i%%2 == 1) {
+				if( (Analysis == "1RMBadillo2010" || analysisCross[1] == "1RMAnyExercise") & Eccon == "ecS" & i%%2 == 1) {
 					discardedCurves = c(i,discardedCurves)
 					discardingCurves = TRUE
 					next;
@@ -1456,7 +1598,7 @@ doProcess <- function(options) {
 			curves = curves[-discardedCurves,]
 
 		rownames(paf)=rownames(curves)
-		print("--------CURVES--------------")
+		print("--------CURVES (propulsive is not calculated yet) --------------")
 		print(curves)
 		print("----------PAF---------------")
 		print(paf)
@@ -1481,19 +1623,33 @@ doProcess <- function(options) {
 				analysisCrossVertVars = unlist(strsplit(analysisCross[2], "\\,"))
 				paintCrossVariables(paf, analysisCross[3], analysisCrossVertVars[1], 
 						    analysisCross[4], "LEFT", Title,
-						    singleFile,Eccon,mySeries)
+						    singleFile,Eccon,mySeries, 
+						    FALSE, FALSE, OutputData1) 
 				par(new=T)
 				paintCrossVariables(paf, analysisCross[3], analysisCrossVertVars[2], 
 						    analysisCross[4], "RIGHT", "",
-						    singleFile,Eccon,mySeries)
+						    singleFile,Eccon,mySeries, 
+						    FALSE, FALSE, OutputData1) 
 			} else
 				paintCrossVariables(paf, analysisCross[3], analysisCross[2], 
 						    analysisCross[4], "ALONE", Title,
-						    singleFile,Eccon,mySeries)
+						    singleFile,Eccon,mySeries, 
+						    FALSE, FALSE, OutputData1) 
+		}
+		else if(analysisCross[1] == "1RMAnyExercise") {
+			mySeries = "1"
+			if(! singleFile)
+				mySeries = curves[,8]
+
+			paintCrossVariables(paf, "Load", "Speed", 
+					    "mean", "ALONE", Title,
+					    singleFile,Eccon,mySeries, 
+					    analysisCross[2], analysisCross[3], #speed1RM, method
+					    OutputData1) 
 		}
 		else if(Analysis == "1RMBadillo2010") {
-			paint1RMBadillo2010(paf, Title)
-		}
+			paint1RMBadillo2010(paf, Title, OutputData1)
+		} 
 		
 		if(Analysis == "curves" || writeCurves) {
 			if(singleFile)
