@@ -52,18 +52,20 @@ mass = float(sys.argv[6])
 smoothingOneEC = float(sys.argv[7])
 smoothingOneC = float(sys.argv[8])
 eccon = sys.argv[9]				#contraction "ec" or "c"
-heightHigherCondition = int(sys.argv[10])
-heightLowerCondition = int(sys.argv[11])
-meanSpeedHigherCondition = float(sys.argv[12])
-meanSpeedLowerCondition = float(sys.argv[13])
-maxSpeedHigherCondition = float(sys.argv[14])
-maxSpeedLowerCondition = float(sys.argv[15])
-powerHigherCondition = int(sys.argv[16])
-powerLowerCondition = int(sys.argv[17])
-peakPowerHigherCondition = int(sys.argv[18])
-peakPowerLowerCondition = int(sys.argv[19])
-mainVariable = sys.argv[20]
-w_serial_port = sys.argv[21]
+analysisOptions = sys.argv[10]			#["p","none"]: propulsive or none
+heightHigherCondition = int(sys.argv[11])
+heightLowerCondition = int(sys.argv[12])
+meanSpeedHigherCondition = float(sys.argv[13])
+meanSpeedLowerCondition = float(sys.argv[14])
+maxSpeedHigherCondition = float(sys.argv[15])
+maxSpeedLowerCondition = float(sys.argv[16])
+powerHigherCondition = int(sys.argv[17])
+powerLowerCondition = int(sys.argv[18])
+peakPowerHigherCondition = int(sys.argv[19])
+peakPowerLowerCondition = int(sys.argv[20])
+mainVariable = sys.argv[21]
+inverted = sys.argv[22]
+w_serial_port = sys.argv[23]
 
 delete_initial_time = 20			#delete first records because there's encoder bug
 #w_baudrate = 9600                           # Setting the baudrate of Chronopic(9600)
@@ -82,13 +84,9 @@ direction_completed = -1		# 1 or -1
 #This will be useful to know the start of movement
 
 frames_pull_top1 = list()
-frames_pull_top2 = list()
 frames_push_bottom1 = list()
-frames_push_bottom2 = list()
 previous_frame_change = 0
 
-lag=20
-
 mode = "graph"
 #mode = "text"
 
@@ -165,37 +163,111 @@ def calculate_all_in_r(temp, top_values, bottom_values, direction_now,
 
 		myR.assign('a',temp[start:end])
 		
+		#declare
+		x_ini = 0	
+		
+		#this will have same values than graph.R:
+		#1) first remove at start with reduceCurveBySpeed
+		#2) do speed and accel for curve once reducedCurveBySpeed
+		#3) find propulsive (if appropiate)
+		#4) remove at end with propulsive (if appropiate)
+
+		#1) first remove at start with reduceCurveBySpeed
 		if direction_now == -1:
-			myR.run('speed <- smooth.spline( 1:length(a), a, spar=smoothingOne)')
+			#some variables only used for cutting
+			myR.run('speedCut <- smooth.spline( 1:length(a), a, spar=smoothingOne)')
+
 
 			#reduce curve by speed, the same way as graph.R
-			myR.run('b=extrema(speed$y)')
-			myR.run('maxSpeedT <- min(which(speed$y == max(speed$y)))')
+			myR.run('b=extrema(speedCut$y)')
+			myR.run('maxSpeedT <- min(which(speedCut$y == max(speedCut$y)))')
 			maxSpeedT = myR.get('maxSpeedT')
 			bcrossLen = myR.get('length(b$cross[,2])')
 			bcross = myR.get('b$cross[,2]')
+			
+			#debug
+			b = myR.get('b')
+			print("printing bbbbbbbbbbbb")
+			print(b)
+			print("printing bbbbbbbbbbbb cross")
+			print(bcross)
+			print("printing bbbbbbbbbbbb maxSpeedT")
+			print(maxSpeedT)
+
 			if bcrossLen == 0:
-				return
+				x_ini = 0
 			if bcrossLen == 1:
-				x_ini = bcrossLen
+				x_ini = bcross	#if bcross has only one item, then this fails: 'bcross[0]'. Just do 'bcross'
 			else:
+				x_ini = bcross[0]	#not 1, we are in python now
 				for i in bcross:
 					if i < maxSpeedT:
 						x_ini = i  #left adjust
 			
-			myR.assign('a',temp[start+x_ini:end])
-	
+			myR.assign('a',temp[(start+x_ini):end])
+			#parenthesis [( )] were totally needed in this operation!!
+			#eg:
+			#k=seq(1:100)
+			#> kwoParentheses = k[10+10:90]
+			#> length(kwoParentheses)
+			#[1] 81
+			#> fivenum(kwoParentheses)
+			#[1]  20  40  60  80 100
+			
+			#> kwParentheses = k[(10+10):90]
+			#> length(kwParentheses)
+			#[1] 71
+			#> fivenum(kwParentheses)
+			#[1] 20.0 37.5 55.0 72.5 90.0
+
+
+
+		#2) do speed and accel for curve once reducedCurveBySpeed
 		myR.run('speed <- smooth.spline( 1:length(a), a, spar=smoothingOne)')
+		myR.run('accel <- predict( speed, deriv=1 )')
+
+	
 		myR.run('a.cumsum <- cumsum(a)')
 		myR.run('range <- abs(a.cumsum[length(a)]-a.cumsum[1])')
-		myR.run('accel <- predict( speed, deriv=1 )')
+
+
+		#3) find propulsive (if appropiate)
+		if direction_now == -1 and analysisOptions == "p":
+			myR.run('accelCut <- predict( speed, deriv=1 )')
+			myR.run('accelCut$y <- accelCut$y * 1000') #input data is in mm, conversion to m
+			myR.run('propulsiveData <- which(accelCut$y <= -9.81)') 
+			propulsiveData = myR.get('propulsiveData') 
+			propulsiveDataLength = myR.get('length(propulsiveData)') 
+			if propulsiveDataLength > 0:
+				end = min(propulsiveData)
+
+			#myR.assign('x_ini',x_ini)
+			myR.assign('end',end)
+
+			#4) remove at end with propulsive (if appropiate)
+			myR.run('speed$y <- speed$y[1:end]')
+			myR.run('accel$y <- accel$y[1:end]')
+
+		
+		print("new curve")
+		print(start+x_ini)
+		myspeedy=myR.get('speed$y')
+		print(myspeedy)
+
+
+
 		myR.run('accel$y <- accel$y * 1000') #input data is in mm, conversion to m
 #		if isJump == "True":
 		myR.run('force <- mass*(accel$y+9.81)')
 #		else:
 #			myR.run('force <- mass*accel$y')
 		myR.run('power <- force*speed$y')
-		myR.run('meanPower <- mean(abs(power))')
+
+		if eccon == "c":
+			myR.run('meanPower <- mean(power)')
+		else:
+			myR.run('meanPower <- mean(abs(power))')
+		
 		myR.run('peakPower <- max(power)')
 		
 		#without the 'min', if there's more than one value it returns a list and this make crash later in
@@ -466,9 +538,8 @@ if __name__ == '__main__':
 	temp = list()		#raw values
 	temp_cumsum = list()	#cumulative sums of raw values
 	temp_cumsum.append(0)
-	temp_speed = list()
 	w_time = datetime.now().second
-	#print "start read data"
+	print "start read data"
 	# Detecting if serial port is available and Recording the data from Chronopic.
 	for i in xrange(delete_initial_time):
 		#if ser.readable(): #commented because don't work on linux
@@ -494,17 +565,18 @@ if __name__ == '__main__':
 
 		#if ser.readable(): #commented because don't work on linux
 		byte_data = ser.read()
+
 		# conver HEX to INT value
 		signedChar_data = unpack('b' * len(byte_data), byte_data)[0]
-    
+		
+		# invert sign if inverted is selected
+		if inverted == 1:
+			signedChard_data *= -1
+
 		temp.append(signedChar_data)
 		if(i>0):
 			temp_cumsum.append(temp_cumsum[i-1]+signedChar_data)
-		if(i>lag):
-			temp_speed.append(1.0*(temp_cumsum[i]-temp_cumsum[i-lag])/lag)
-		else:
-			temp_speed.append(0)
-
+		
 		msCount = msCount +1
 		if msCount == 1000 :
 			secondsLeft = secondsLeft -1
@@ -525,29 +597,31 @@ if __name__ == '__main__':
 
 				k=list(temp_cumsum[previous_frame_change:i-direction_change_period])
 	
-				phase = 0
-				speed = 0
-	
 				if direction_now == 1:
-					#we are going up, we passed the ditection_change_count
+					#we are going up, we passed the direction_change_count
 					#then we can record the bottom moment
-					#and print speed on going down
-					new_frame_change = previous_frame_change+k.index(min(k)) 
+					#and print speed on going down (Not done anymore)
+					
+					#this has (maybe) 0,-1,0,0,0,0,0, .... (and -1 can be selected (min(k)).
+					#Then, do not pass this to frames_push_bottom, pass the next new_frame_change
+					
+					new_frame_change = previous_frame_change+k.index(min(k))
+					print("NFC 1 1 (start zeros on the bottom) %i" % new_frame_change) 
+					
 					frames_push_bottom1.append(new_frame_change)
+
 					new_frame_change = previous_frame_change+len(k)-1-k[::-1].index(min(k))
-					frames_push_bottom2.append(new_frame_change)
-					phase = " down"
-					if previous_frame_change != 0 and new_frame_change != 0:
-						speed = min(temp_speed[previous_frame_change:new_frame_change])
+					print("NFC 1 2 (end zeros on the bottom) %i" % new_frame_change) 
+					
 				else:
 					new_frame_change = previous_frame_change+k.index(max(k))
+					print("NFC 2 1 (start zeros on the top) %i" % new_frame_change) 
+					
 					frames_pull_top1.append(new_frame_change)
+					
 					new_frame_change = previous_frame_change+len(k)-1-k[::-1].index(max(k))
-					frames_pull_top2.append(new_frame_change)
-					phase = "   up"
-					if previous_frame_change != 0 and new_frame_change != 0:
-						speed = max(temp_speed[previous_frame_change:new_frame_change])
-	
+					print("NFC 2 2 (end zeros on the top) %i" % new_frame_change) 
+					
 
 				if len(frames_pull_top1)>0 and len(frames_push_bottom1)>0:
 					calculate_all_in_r(temp, frames_pull_top1, frames_push_bottom1, 
