@@ -102,6 +102,7 @@ public class Constants
 	public const string TempMultiChronopicTable = "tempMultiChronopic"; //TODO
 	public const string EncoderTable = "encoder";
 	public const string EncoderExerciseTable = "encoderExercise";
+	public const string Encoder1RMTable = "encoder1RM";
 
 	//tests types
 	public const string JumpTypeTable = "jumpType";
@@ -309,8 +310,10 @@ public class Constants
 	public static string AllPulsesName = Catalog.GetString("See all pulses");
 
 	//fileNames
-	public static string FileNameLogo = "chronojump-boscosystem_white_bg.png";
-	public static string FileNameLogo320 = "chronojump-boscosystem_320.png";
+	//public static string FileNameLogo = "chronojump-boscosystem_white_bg.png";
+	//public static string FileNameLogo320 = "chronojump-boscosystem_320.png";
+	public static string FileNameLogo = "chronojump-logo-2013.png";
+	public static string FileNameLogo320 = "chronojump-logo-2013_320.png";
 	public static string FileNameCSS = "report_web_style.css";
 	public static string FileNameIcon = "chronojump_icon.png";
 	public static string FileNameIconGraph = "chronojump_icon_graph.png";
@@ -537,7 +540,7 @@ public class Constants
 
 	//heightmetric contains 2 spins
 	public enum GenericWindowShow {
-		ENTRY, ENTRY2, ENTRY3, SPININT, SPINDOUBLE, HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
+		ENTRY, ENTRY2, ENTRY3, SPININT, SPINDOUBLE, HBOXSPINDOUBLE2, HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
 	}
 	
 	public const string PrefVersionAvailable = "versionAvailable";
@@ -588,15 +591,19 @@ public class Constants
 
 	public static string EncoderDataTemp = "chronojump-last-encoder-data.txt";
 	public static string EncoderCurvesTemp = "chronojump-last-encoder-curves.txt";
+	public static string EncoderAnalyzeTableTemp = "chronojump-last-encoder-analyze-table.txt";
 	public static string EncoderGraphTemp = "chronojump-last-encoder-graph.png";
 	public static string EncoderStatusTemp = "chronojump-encoder-status.txt";
 	public static string EncoderExportTemp = "chronojump-export.csv";
+	public static string EncoderSpecialDataTemp = "chronojump-special-data.txt"; //variable;result (eg. "1RM;82.78")
 
 	//note next has 40 chars, and its used also in encoder/graph.R to detect how a file will be treated
 	//if this name changes, change it in encoder/graph.R
 	public static string EncoderGraphInputMulti = "chronojump-encoder-graph-input-multi.csv"; 
 
 	public enum EncoderCheckFileOp { ANALYZE_EXPORT_ALL_CURVES, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
+	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
+	public enum ContextMenu { NONE, EDITDELETE, DELETE }
 
 	public enum DoubleContact {
 		FIRST, AVERAGE, LAST
