@@ -51,6 +51,7 @@ public class EncoderParams
 	private int peakPowerLowerCondition;
 	private string mainVariable;
 	private string decimalSeparator;	//used in export data from R to csv
+	private bool inverted;
 
 	public EncoderParams()
 	{
@@ -58,13 +59,13 @@ public class EncoderParams
 
 	//to encoder capture (pyserial_pyper.py)
 	public EncoderParams(int time, int minHeight, int exercisePercentBodyWeight, string mass, 
-			string smoothEccCon, string smoothCon, string eccon,
+			string smoothEccCon, string smoothCon, string eccon, string analysisOptions,
 			double heightHigherCondition, double heightLowerCondition, 
 			double meanSpeedHigherCondition, double meanSpeedLowerCondition, 
 			double maxSpeedHigherCondition, double maxSpeedLowerCondition, 
 			int powerHigherCondition, int powerLowerCondition, 
 			int peakPowerHigherCondition, int peakPowerLowerCondition,
-			string mainVariable)
+			string mainVariable, bool inverted)
 	{
 		this.time = time;
 		this.minHeight = minHeight;
@@ -73,6 +74,7 @@ public class EncoderParams
 		this.smoothEccCon = smoothEccCon;
 		this.smoothCon = smoothCon;
 		this.eccon = eccon;
+		this.analysisOptions = analysisOptions;
 		this.heightHigherCondition = heightHigherCondition;
 		this.heightLowerCondition = heightLowerCondition;
 		this.meanSpeedHigherCondition = meanSpeedHigherCondition;
@@ -84,12 +86,17 @@ public class EncoderParams
 		this.peakPowerHigherCondition = peakPowerHigherCondition;
 		this.peakPowerLowerCondition = peakPowerLowerCondition;
 		this.mainVariable = mainVariable;
+		this.inverted = inverted;
 	}
 	
 	public string ToString1 () 
 	{
+		string analysisOptionsPrint = analysisOptions;
+		if(analysisOptionsPrint == "")
+			analysisOptionsPrint = "none";
+
 		return time.ToString() + " " + minHeight.ToString() + " " + exercisePercentBodyWeight.ToString() + 
-			" " + mass.ToString() + " " + smoothEccCon + " " + smoothCon + " " + eccon +
+			" " + mass.ToString() + " " + smoothEccCon + " " + smoothCon + " " + eccon + " " + analysisOptionsPrint +
 			" " + heightHigherCondition.ToString() +	" " + heightLowerCondition.ToString() +
 			" " + Util.ConvertToPoint(meanSpeedHigherCondition.ToString()) + 	
 			" " + Util.ConvertToPoint(meanSpeedLowerCondition.ToString()) +
@@ -97,7 +104,7 @@ public class EncoderParams
 			" " + Util.ConvertToPoint(maxSpeedLowerCondition.ToString()) +
 			" " + powerHigherCondition.ToString() + 	" " + powerLowerCondition.ToString() +
 			" " + peakPowerHigherCondition.ToString() + 	" " + peakPowerLowerCondition.ToString() +
-			" " + mainVariable;
+			" " + mainVariable + " " + Util.BoolToInt(inverted).ToString();
 	}
 	
 	//to graph.R	
@@ -146,15 +153,17 @@ public class EncoderStruct
 	public string OutputGraph;
 	public string OutputData1;
 	public string OutputData2;
+	public string SpecialData;
 	public EncoderParams Ep;
 
 	public EncoderStruct(string InputData, string OutputGraph, string OutputData1, string OutputData2,
-		       EncoderParams Ep)
+			string SpecialData, EncoderParams Ep)
 	{
 		this.InputData = InputData;
 		this.OutputGraph = OutputGraph;
 		this.OutputData1 = OutputData1;
 		this.OutputData2 = OutputData2;
+		this.SpecialData = SpecialData;
 		this.Ep = Ep;
 	}
 
@@ -188,7 +197,8 @@ public class EncoderCurve
 	}
 
 	//used on TreeView analyze
-	public EncoderCurve (string n, string series, string exercise, double extraWeight,
+	public EncoderCurve (string n, string series, string exercise, 
+			double extraWeight, double displacedWeight,
 			string start, string duration, string height,
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
@@ -198,6 +208,7 @@ public class EncoderCurve
 		this.Series = series;
 		this.Exercise = exercise;
 		this.ExtraWeight = extraWeight;
+		this.DisplacedWeight = displacedWeight;
 		this.Start = start;
 		this.Duration = duration;
 		this.Height = height;
@@ -213,7 +224,8 @@ public class EncoderCurve
 	public string ToCSV() {
 		string sep = ";";
 		return 
-			N + sep + Series + sep + Exercise + sep + ExtraWeight + sep + 
+			N + sep + Series + sep + Exercise + sep + 
+			ExtraWeight + sep + DisplacedWeight + sep + 
 			Start + sep + Duration + sep + Height + sep + 
 			MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
 			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
@@ -224,6 +236,7 @@ public class EncoderCurve
 	public string Series;
 	public string Exercise;
 	public double ExtraWeight;
+	public double DisplacedWeight;
 	public string Start;
 	public string Duration;
 	public string Height;
@@ -254,7 +267,7 @@ public class EncoderSQL
 	public string description;
 	public string future1;	//active or inactive curves
 	public string future2;	//URL of video of signals
-	public string future3;
+	public string future3;	//inverted
 	public string exerciseName;
 	
 	public string ecconLong;
@@ -438,6 +451,7 @@ public class EncoderExercise
 	public int percentBodyWeight;
 	public string ressistance;
 	public string description;
+	public double speed1RM;
 
 	public EncoderExercise() {
 	}
@@ -446,15 +460,63 @@ public class EncoderExercise
 		this.name = name;
 	}
 
-	public EncoderExercise(int uniqueID, string name, int percentBodyWeight, string ressistance, string description)
+	public EncoderExercise(int uniqueID, string name, int percentBodyWeight, string ressistance, string description, double speed1RM)
 	{
 		this.uniqueID = uniqueID;
 		this.name = name;
 		this.percentBodyWeight = percentBodyWeight;
 		this.ressistance = ressistance;
 		this.description = description;
+		this.speed1RM = speed1RM;
 	}
 
 	~EncoderExercise() {}
 }
 
+public class Encoder1RM
+{
+	public int uniqueID;
+	public int personID;
+	public int sessionID;
+	public int exerciseID;
+	public double load1RM;
+	
+	public string personName;
+	public string exerciseName;
+	
+	public Encoder1RM() {
+	}
+
+	public Encoder1RM(int uniqueID, int personID, int sessionID, int exerciseID, double load1RM)
+	{
+		this.uniqueID = uniqueID;
+		this.personID = personID;
+		this.sessionID = sessionID;
+		this.exerciseID = exerciseID;
+		this.load1RM = load1RM;
+	}
+
+	public Encoder1RM(int uniqueID, int personID, int sessionID, int exerciseID, double load1RM, string personName, string exerciseName)
+	{
+		this.uniqueID = uniqueID;
+		this.personID = personID;
+		this.sessionID = sessionID;
+		this.exerciseID = exerciseID;
+		this.load1RM = load1RM;
+		this.personName = personName;
+		this.exerciseName = exerciseName;
+	}
+
+	public string [] ToStringArray() {
+		string [] s = { uniqueID.ToString(), load1RM.ToString() };
+		return s;
+	}
+	
+	public string [] ToStringArray2() {
+		string [] s = { uniqueID.ToString(), personName, exerciseName, load1RM.ToString() };
+		return s;
+	}
+
+
+	~Encoder1RM() {}
+}
