@@ -73,12 +73,17 @@ public class GenericWindow
 	[Widget] Gtk.Box hbox_entry3;
 	[Widget] Gtk.Label label_entry3;
 	[Widget] Gtk.Entry entry3;
+
+	[Widget] Gtk.Box hbox_spin_double2;
+	[Widget] Gtk.Label label_spin_double2;
+	[Widget] Gtk.SpinButton spin_double2;
 	
 	private ArrayList nonSensitiveRows;
 
 	static GenericWindow GenericWindowBox;
 	
 	private TreeStore store;
+	private Constants.ContextMenu genericWinContextMenu;
 	
 	//used to read data, see if it's ok, and print an error message.
 	//if all is ok, destroy it with HideAndNull()
@@ -151,6 +156,7 @@ public class GenericWindow
 		hbox_entry3.Hide();
 		hbox_spin_int.Hide();
 		spin_double.Hide();
+		hbox_spin_double2.Hide();
 		hbox_height_metric.Hide();
 		hbox_combo_full_line.Hide();
 		hbox_all_none_selected.Hide();
@@ -187,6 +193,11 @@ public class GenericWindow
 			spin_double.Show();
 			spin_double.IsEditable = editable;
 		}
+		else if(stuff == Constants.GenericWindowShow.HBOXSPINDOUBLE2) {
+			hbox_spin_double2.Show();
+			spin_double2.IsEditable = editable;
+			spin_double2.Sensitive = editable;
+		}
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC) {
 			hbox_height_metric.Show();
 		}
@@ -223,6 +234,8 @@ public class GenericWindow
 			hbox_spin_int.Show();
 		else if(stuff == Constants.GenericWindowShow.SPINDOUBLE)
 			spin_double.Show();
+		else if(stuff == Constants.GenericWindowShow.HBOXSPINDOUBLE2)
+			hbox_spin_double2.Show();
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC)
 			hbox_height_metric.Show();
 		else if(stuff == Constants.GenericWindowShow.COMBO) {
@@ -253,6 +266,13 @@ public class GenericWindow
 		spin_int.SetRange(min, max);
 	}
 	
+	public void SetSpinDouble2Value(double num) {
+		spin_double2.Value = num;
+	}
+	public void SetSpinDouble2Increments(double min, double max) {
+		spin_double2.SetIncrements(min, max);
+	}
+	
 	public void SetComboValues(string [] values, string current) {
 		combo = ComboBox.NewText ();
 		UtilGtk.ComboUpdate(combo, values, "");
@@ -362,7 +382,7 @@ public class GenericWindow
 	
 	//data is an ArrayList of strings[], each string [] is a row, each of its strings is a column
 	public void SetTreeview(string [] columnsString, bool addCheckbox, 
-			ArrayList data, ArrayList myNonSensitiveRows, bool contextMenu) 
+			ArrayList data, ArrayList myNonSensitiveRows, Constants.ContextMenu contextMenu) 
 	{
 		//adjust window to be bigger
 		generic_window.Resizable = true;
@@ -376,15 +396,22 @@ public class GenericWindow
 		nonSensitiveRows = myNonSensitiveRows;
 	
 Log.WriteLine("aaaaaaaaaaaaaaaa1");	
-		foreach (string [] line in data) 
+		foreach (string [] line in data) {
 			store.AppendValues (line);
+			Log.WriteLine(Util.StringArrayToString(line,"\n"));
+		}
 Log.WriteLine("aaaaaaaaaaaaaaaa2");	
 
+		genericWinContextMenu = contextMenu;
+
 		treeview.CursorChanged += on_treeview_cursor_changed; 
-		if(contextMenu) {
+		if(contextMenu == Constants.ContextMenu.EDITDELETE) {
 			button_row_edit = new Gtk.Button();
 			button_row_delete = new Gtk.Button();
 			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
+		} else if(contextMenu == Constants.ContextMenu.DELETE) {
+			button_row_delete = new Gtk.Button();
+			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
 		}
 	}
 	
@@ -540,15 +567,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		TreeModel model = treeview.Model;
 		if (e.Button == 3) {
 			TreeIter iter = new TreeIter();
-			//TreeModel myModel = tv.Model;
 			if (tv.Selection.GetSelected (out model, out iter)) {
-/*
-Log.WriteLine((string) store.GetValue (iter, 0));
-//Log.WriteLine((string) store.GetValue (iter, 1));
-Log.WriteLine((string) store.GetValue (iter, 2));
-Log.WriteLine((string) store.GetValue (iter, 3));
-*/
-				//TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
 				TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
 				treeviewContextMenu();
 			}
@@ -560,14 +579,20 @@ Log.WriteLine((string) store.GetValue (iter, 3));
 		Menu myMenu = new Menu ();
 		Gtk.MenuItem myItem;
 
-		myItem = new MenuItem ( Catalog.GetString("Edit selected") );
-		myItem.Activated += on_edit_selected_clicked;
-		myMenu.Attach( myItem, 0, 1, 0, 1 );
+		if(genericWinContextMenu == Constants.ContextMenu.EDITDELETE) {
+			myItem = new MenuItem ( Catalog.GetString("Edit selected") );
+			myItem.Activated += on_edit_selected_clicked;
+			myMenu.Attach( myItem, 0, 1, 0, 1 );
 
-
-		myItem = new MenuItem ( Catalog.GetString("Delete selected") );
-		myItem.Activated += on_delete_selected_clicked;
-		myMenu.Attach( myItem, 0, 1, 1, 2 );
+			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
+			myItem.Activated += on_delete_selected_clicked;
+			myMenu.Attach( myItem, 0, 1, 1, 2 );
+		}
+		else if(genericWinContextMenu == Constants.ContextMenu.DELETE) {
+			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
+			myItem.Activated += on_delete_selected_clicked;
+			myMenu.Attach( myItem, 0, 1, 0, 1 );
+		}
 
 		myMenu.Popup();
 		myMenu.ShowAll();
@@ -686,6 +711,13 @@ Log.WriteLine((string) store.GetValue (iter, 3));
 	public double SpinDoubleSelected {
 		get { return (double) spin_double.Value; }
 	}
+
+	public string LabelSpinDouble2 {
+		set { label_spin_double2.Text = value; }
+	}
+	public double SpinDouble2Selected {
+		get { return (double) spin_double2.Value; }
+	}
 	
 	public string TwoSpinSelected {
 		get { return ((int) spin_feet.Value).ToString() + ":" + ((int) spin_inches.Value).ToString(); }
