@@ -952,7 +952,7 @@ public class RepairJumpRjWindow
 		}
 
 		//save it deleting the old first for having the same uniqueID
-		Sqlite.Delete(Constants.JumpRjTable, jumpRj.UniqueID);
+		Sqlite.Delete(false, Constants.JumpRjTable, jumpRj.UniqueID);
 		jumpRj.InsertAtDB(false, Constants.JumpRjTable); 
 		/*
 		SqliteJump.InsertRj("jumpRj", jumpRj.UniqueID.ToString(), jumpRj.PersonID, jumpRj.SessionID, 
