@@ -25,6 +25,7 @@ using Glade;
 using GLib; //for Value
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List
 using Mono.Unix;
 using System.Threading;
 using System.IO; 
@@ -61,6 +62,7 @@ public class PersonRecuperateWindow {
 	protected int columnId = 0;
 	protected int firstColumn = 0;
 	protected int pDN;
+	protected Gtk.CheckButton app1_checkbutton_video;
 	
 	public Gtk.Button fakeButtonDone;
 
@@ -97,12 +99,14 @@ public class PersonRecuperateWindow {
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 	
-	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, int pDN)
+	static public PersonRecuperateWindow Show (Gtk.Window parent, Session currentSession, 
+			int pDN, Gtk.CheckButton app1_checkbutton_video)
 	{
 		if (PersonRecuperateWindowBox == null) {
 			PersonRecuperateWindowBox = new PersonRecuperateWindow (parent, currentSession);
 		}
 		PersonRecuperateWindowBox.pDN = pDN;
+		PersonRecuperateWindowBox.app1_checkbutton_video = app1_checkbutton_video;
 
 		PersonRecuperateWindowBox.person_recuperate.Show ();
 		
@@ -250,7 +254,7 @@ public class PersonRecuperateWindow {
 			Person person = SqlitePerson.Select(Convert.ToInt32(selected));
 
 			personAddModifyWin = PersonAddModifyWindow.Show(
-					parent, currentSession, person, pDN, true); //comes from recuperate window
+					parent, currentSession, person, pDN, app1_checkbutton_video, true); //comes from recuperate window
 			personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
 		}
 	}
@@ -364,12 +368,14 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 		treeview_person_recuperate.Selection.Changed += onSelectionEntry;
 	}
 
-	static public new PersonsRecuperateFromOtherSessionWindow Show (Gtk.Window parent, Session currentSession)
+	static public new PersonsRecuperateFromOtherSessionWindow Show (
+			Gtk.Window parent, Session currentSession, Gtk.CheckButton app1_checkbutton_video)
 	{
 		if (PersonsRecuperateFromOtherSessionWindowBox == null) {
 			PersonsRecuperateFromOtherSessionWindowBox = 
 				new PersonsRecuperateFromOtherSessionWindow (parent, currentSession);
 		}
+		PersonsRecuperateFromOtherSessionWindowBox.app1_checkbutton_video = app1_checkbutton_video;
 		PersonsRecuperateFromOtherSessionWindowBox.person_recuperate.Show ();
 		
 		return PersonsRecuperateFromOtherSessionWindowBox;
@@ -571,7 +577,7 @@ public class PersonsRecuperateFromOtherSessionWindow : PersonRecuperateWindow
 					Person person = SqlitePerson.Select(
 							Convert.ToInt32(treeview_person_recuperate.Model.GetValue(iter, 1)) );
 					personAddModifyWin = PersonAddModifyWindow.Show(
-							parent, currentSession, person, pDN, true); //comes from recuperate window
+							parent, currentSession, person, pDN, app1_checkbutton_video, true); //comes from recuperate window
 					PersonAddModifyWindow.MakeVisible();
 					personAddModifyWin.FakeButtonAccept.Clicked += new EventHandler(on_edit_current_person_accepted);
 					personAddModifyWin.FakeButtonCancel.Clicked += new EventHandler(on_edit_current_person_cancelled);
@@ -895,6 +901,7 @@ public class PersonAddModifyWindow
 	private string sex = Constants.M;
 	private double weightIni;
 	int pDN;
+	Gtk.CheckButton app1_checkbutton_video;
 	
 	private int serverUniqueID;
 
@@ -983,22 +990,29 @@ public class PersonAddModifyWindow
 	CapturerBin capturer;
 	void on_button_take_photo_clicked (object o, EventArgs args) 
 	{
+		List<LongoMatch.Video.Utils.Device> devices = LongoMatch.Video.Utils.Device.ListVideoDevices();
+		if(devices.Count == 0) {
+			new DialogMessage(Constants.MessageTypes.WARNING, Constants.CameraNotFound);
+			return;
+		}
+
+		//deactivate camera to allow camera on edit person. videoOn will have same value to light checkbutton again later
+		app1_checkbutton_video.Active = false;
 
-		new DialogMessage(Constants.MessageTypes.INFO, 
-				Catalog.GetString("Sorry, photos are disabled on this version."));
-		/*
 		capturer = new CapturerBin();
 		CapturePropertiesStruct s = new CapturePropertiesStruct();
 
-		s.CaptureSourceType = CaptureSourceType.Raw;
+		s.DeviceID = devices[0].ID;
+
+		s.CaptureSourceType = CaptureSourceType.System;
 
 		capturer.CaptureProperties = s;
 		capturer.Type = CapturerType.Snapshot;
 		capturer.Visible=true;
 		capturer.NewSnapshot += on_snapshot_done;
 		capturer.NewSnapshotMini += on_snapshot_mini_done;
-		
- 		capturerWindow = new Gtk.Window("Capturer");
+
+		capturerWindow = new Gtk.Window("Capturer");
 		capturerWindow.Add(capturer);
 		capturerWindow.Modal=true;
 		capturerWindow.SetDefaultSize(400,400);
@@ -1008,8 +1022,8 @@ public class PersonAddModifyWindow
 		capturerWindow.ShowAll();
 		capturerWindow.Present();
 		capturerWindow.DeleteEvent += delegate(object sender, DeleteEventArgs e) {capturer.Close(); capturer.Dispose(); person_win.Show(); };
+		
 		capturer.Run();
-		*/
 	}
 
 	private void on_snapshot_done(Pixbuf pixbuf) {
@@ -1125,7 +1139,9 @@ public class PersonAddModifyWindow
 	}
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
-			Session mySession, Person currentPerson, int pDN, bool comesFromRecuperateWin)
+			Session mySession, Person currentPerson, int pDN, 
+			Gtk.CheckButton app1_checkbutton_video,
+			bool comesFromRecuperateWin)
 	{
 		if (comesFromRecuperateWin) 
 			PersonAddModifyWindowBox = null;
@@ -1135,6 +1151,7 @@ public class PersonAddModifyWindow
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
+		PersonAddModifyWindowBox.app1_checkbutton_video = app1_checkbutton_video;
 		PersonAddModifyWindowBox.comesFromRecuperateWin = comesFromRecuperateWin;
 
 		//No more hide cancel button.
@@ -2059,7 +2076,8 @@ public class PersonShowAllEventsWindow {
 		createComboPersons(sessionID, currentPerson.UniqueID.ToString(), currentPerson.Name);
 		createTreeView(treeview_person_show_all_events);
 		store = new TreeStore( typeof (string), typeof (string), typeof (string), typeof (string), 
-				typeof (string), typeof(string), typeof(string), typeof(string), typeof(string), typeof(string) );
+				typeof (string), typeof(string), typeof(string), typeof(string), typeof(string), typeof(string),
+			       	typeof (string), typeof(string));
 		treeview_person_show_all_events.Model = store;
 		fillTreeView(treeview_person_show_all_events,store, currentPerson.UniqueID);
 	}
@@ -2104,7 +2122,8 @@ public class PersonShowAllEventsWindow {
 		string myText = UtilGtk.ComboGetActive(combo_persons);
 		if(myText != "") {
 			store = new TreeStore( typeof (string), typeof (string), typeof (string), typeof (string), 
-					typeof (string), typeof(string), typeof(string), typeof(string), typeof(string), typeof(string) );
+					typeof (string), typeof(string), typeof(string), typeof(string), typeof(string), typeof(string),
+				       	typeof (string), typeof(string));
 			treeview_person_show_all_events.Model = store;
 			
 			string [] myStringFull = myText.Split(new char[] {':'});
@@ -2136,6 +2155,8 @@ public class PersonShowAllEventsWindow {
 		tv.AppendColumn ( Catalog.GetString ("Reaction\ntime"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("Pulses"), new CellRendererText(), "text", count++);
 		tv.AppendColumn ( Catalog.GetString ("MultiChronopic"), new CellRendererText(), "text", count++);
+		tv.AppendColumn ( Catalog.GetString ("Encoder signals"), new CellRendererText(), "text", count++);
+		tv.AppendColumn ( Catalog.GetString ("Encoder curves"), new CellRendererText(), "text", count++);
 	}
 	
 	protected void fillTreeView (Gtk.TreeView tv, TreeStore store, int personID) {
@@ -2146,7 +2167,7 @@ public class PersonShowAllEventsWindow {
 			string [] myStr = myEvent.Split(new char[] {':'});
 
 			store.AppendValues (myStr[0], myStr[1], myStr[2], myStr[3], myStr[4], myStr[5], 
-					myStr[6], myStr[7], myStr[8], myStr[9]);
+					myStr[6], myStr[7], myStr[8], myStr[9], myStr[10], myStr[11]);
 		}
 	}
 	
