@@ -72,7 +72,7 @@ class Sqlite
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "0.92";
+	static string lastChronojumpDatabaseVersion = "0.95";
 
 	public Sqlite() {
 	}
@@ -1208,7 +1208,7 @@ class Sqlite
 			if(currentVersion == "0.88") {
 				dbcon.Open();
 	
-				SqliteEncoder.InsertExercise(true, "Free", 0, "", "");
+				SqliteEncoder.InsertExercise(true, "Free", 0, "", "", "");
 				Log.WriteLine("Added encoder exercise: Free");
 				
 				SqlitePreferences.Update ("databaseVersion", "0.89", true); 
@@ -1232,7 +1232,7 @@ class Sqlite
 			if(currentVersion == "0.90") {
 				dbcon.Open();
 				
-				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "");	
+				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "", "");	
 				Log.WriteLine("Encoder Squat 75% -> 100%");
 				
 				SqlitePreferences.Update ("databaseVersion", "0.91", true); 
@@ -1251,6 +1251,41 @@ class Sqlite
 
 				currentVersion = "0.92";
 			}
+			if(currentVersion == "0.92") {
+				dbcon.Open();
+				
+				SqliteEncoder.UpdateExercise(true, "Bench press", 0, "weight bar", "","0.185");	
+				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "","0.31");	
+				Log.WriteLine("Added speed1RM on encoder exercise");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.93", true); 
+				dbcon.Close();
+
+				currentVersion = "0.93";
+			}
+			if(currentVersion == "0.93") {
+				dbcon.Open();
+				
+				SqliteEncoder.createTable1RM();
+				Log.WriteLine("Added encoder1RM table");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.94", true); 
+				dbcon.Close();
+
+				currentVersion = "0.94";
+			}
+			if(currentVersion == "0.94") {
+				dbcon.Open();
+				
+				SqlitePreferences.Insert ("encoder1RMMethod", 
+						Constants.Encoder1RMMethod.WEIGHTED2.ToString());
+				Log.WriteLine("Added encoder1RMMethod");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.95", true); 
+				dbcon.Close();
+
+				currentVersion = "0.95";
+			}
 		}
 
 		//if changes are made here, remember to change also in CreateTables()
@@ -1367,6 +1402,7 @@ class Sqlite
 		SqliteEncoder.createTableEncoder();
 		SqliteEncoder.createTableEncoderExercise();
 		SqliteEncoder.initializeTableEncoderExercise();
+		SqliteEncoder.createTable1RM();
 
 		//sports
 		creationRate ++;
@@ -1389,6 +1425,9 @@ class Sqlite
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
+		//0.94 - 0.95 Converted DB to 0.95 Added encoder1RMMethod
+		//0.93 - 0.94 Converted DB to 0.94 Added encoder1RM table
+		//0.92 - 0.93 Converted DB to 0.93 Added speed1RM on encoder exercise
 		//0.91 - 0.92 Converted DB to 0.92 Added videoDevice to preferences
 		//0.90 - 0.91 Converted DB to 0.91 Encoder Squat 75% -> 100%
 		//0.89 - 0.90 Converted DB to 0.90 Preferences added propulsive and encoder smooth
