@@ -372,6 +372,36 @@ class SqliteSession : Sqlite
 		}
 		reader_mcs.Close();
 	
+		//select encoder signal of each session
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.EncoderTable + 
+			" WHERE signalOrCurve == 'signal' GROUP BY sessionID ORDER BY sessionID";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader_enc_s;
+		reader_enc_s = dbcmd.ExecuteReader();
+		ArrayList myArray_enc_s = new ArrayList(2);
+		
+		while(reader_enc_s.Read()) {
+			myArray_enc_s.Add (reader_enc_s[0].ToString() + ":" + reader_enc_s[1].ToString() + ":" );
+		}
+		reader_enc_s.Close();
+	
+		//select encoder curve of each session
+		dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.EncoderTable + 
+			" WHERE signalOrCurve == 'curve' GROUP BY sessionID ORDER BY sessionID";
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader_enc_c;
+		reader_enc_c = dbcmd.ExecuteReader();
+		ArrayList myArray_enc_c = new ArrayList(2);
+		
+		while(reader_enc_c.Read()) {
+			myArray_enc_c.Add (reader_enc_c[0].ToString() + ":" + reader_enc_c[1].ToString() + ":" );
+		}
+		reader_enc_c.Close();
+	
 		
 		//close database connection
 		dbcon.Close();
@@ -475,6 +505,28 @@ class SqliteSession : Sqlite
 			}
 			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
 
+			//add encoder signal for each session
+			found = false;
+			foreach (string line_enc_s in myArray_enc_s) {
+				string [] myStringFull = line_enc_s.Split(new char[] {':'});
+				if(myStringFull[0] == mixingSessionID) {
+					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
+					found = true;
+				}
+			}
+			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
+
+			//add encoder curve for each session
+			found = false;
+			foreach (string line_enc_c in myArray_enc_c) {
+				string [] myStringFull = line_enc_c.Split(new char[] {':'});
+				if(myStringFull[0] == mixingSessionID) {
+					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
+					found = true;
+				}
+			}
+			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
+
 			
 			mySessions [count++] = lineNotReadOnly;
 		}
@@ -566,6 +618,32 @@ class SqliteSession : Sqlite
 		dbcmd.CommandText = "Delete FROM " + Constants.MultiChronopicTable + " WHERE sessionID == " + uniqueID;
 		dbcmd.ExecuteNonQuery();
 		
+		//delete from encoder
+		dbcmd.CommandText = "Delete FROM " + Constants.EncoderTable + " WHERE sessionID == " + uniqueID;
+			
+		dbcmd.ExecuteNonQuery();
+		
+
+		//delete encoder signal and curves (and it's videos)
+		ArrayList encoderArray = SqliteEncoder.Select(true, -1, -1, 
+				Convert.ToInt32(uniqueID), "signal", false);
+		foreach(EncoderSQL eSQL in encoderArray) {
+			Util.FileDelete(eSQL.GetFullURL(false));	//signal, don't convertPathToR
+			if(eSQL.future2 != "")
+				Util.FileDelete(eSQL.future2);		//video
+			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
+		}
+		encoderArray = SqliteEncoder.Select(true, -1, -1, 
+				Convert.ToInt32(uniqueID), "curve", false);
+		foreach(EncoderSQL eSQL in encoderArray) {
+			Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
+			/* commented: curve has no video
+			if(eSQL.future2 != "")
+				Util.FileDelete(eSQL.future2);
+			*/
+			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
+		}
+				
 		
 		dbcon.Close();
 	}
