@@ -895,6 +895,9 @@ public class Util
 	public static string GetEncoderCurvesTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderCurvesTemp);
 	}
+	public static string GetEncoderAnalyzeTableTempFileName() {
+		return Path.Combine(Path.GetTempPath(), Constants.EncoderAnalyzeTableTemp);
+	}
 	public static string GetEncoderGraphTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderGraphTemp);
 	}
@@ -907,6 +910,9 @@ public class Util
 	public static string GetEncoderExportTempFileName() {
 		return Path.Combine(Path.GetTempPath(), Constants.EncoderExportTemp);
 	}
+	public static string GetEncoderSpecialDataTempFileName() {
+		return Path.Combine(Path.GetTempPath(), Constants.EncoderSpecialDataTemp);
+	}
 
 
 //	public static void MoveTempToEncoderData(int sessionID, int uniqueID) {
@@ -954,7 +960,7 @@ public class Util
 		return System.IO.Path.Combine(
 				getDataDir(), "encoder", Constants.EncoderScriptGraph);
 	}
-
+	
 	
 	/********** end of encoder paths ************/
 
@@ -1167,12 +1173,14 @@ public class Util
 			es.OutputGraph = es.OutputGraph.Replace("\\","/");
 			es.OutputData1 = es.OutputData1.Replace("\\","/");
 			es.OutputData2 = es.OutputData2.Replace("\\","/");
+			es.SpecialData = es.SpecialData.Replace("\\","/");
 			operatingSystem = "Windows";
 		}
 		
 		//--- way A. passing options to a file
 		string scriptOptions = es.InputData + "\n" + 
-		es.OutputGraph + "\n" + es.OutputData1 + "\n" + es.OutputData2 + "\n" + 
+		es.OutputGraph + "\n" + es.OutputData1 + "\n" + 
+		es.OutputData2 + "\n" + es.SpecialData + "\n" + 
 		es.Ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n";
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
@@ -1248,6 +1256,10 @@ public class Util
 			if (File.Exists(outputFileCheck2))
 				File.Delete(outputFileCheck2);
 		}
+			
+		//delete 1RM data if exists
+		if (File.Exists(es.SpecialData))
+			File.Delete(es.SpecialData);
 	
 		p = new Process();
 		p.StartInfo = pinfo;
@@ -1344,6 +1356,37 @@ public class Util
 		return fileCurve;
 	}
 
+	//used on encoder inverted-noninverted
+	public static void ChangeSign(string fileName) 
+	{
+		string data = ReadFile(fileName, true);
+		if(data != null) {
+			TextWriter writer;
+			try {
+				writer = File.CreateText(fileName);
+			} catch {return;}
+	
+			using (StringReader reader = new StringReader (data)) {
+				do {
+					string line = reader.ReadLine ();
+					if (line == null)
+						break;
+					string [] ints = line.Split(new char[] {','});
+					string sep = "";
+					foreach(string istr in ints) {
+						int i = Convert.ToInt32(istr);
+						i *= -1;
+						writer.Write(sep + i.ToString());
+						sep = ", ";
+					}
+				} while(true);
+			}
+			writer.Flush();
+			((IDisposable)writer).Dispose();
+		}
+	}
+
+
 
 /*
  * currently not used, we copy the assemblies now
